body {
    /* Background image comes from http://subtlepatterns.com/
    * and is CC BY-SA 3.0 - Subtle Patterns © Atle Mo.
    *
    * http://subtlepatterns.com/halftone/
    */
    background-image:url('/static/images/halftone/halftone.png');
    /* Force scrollbar so collapsed divs don't jerk
        * the page around when they grow larger than
        * the page.
    */
    overflow-y: scroll;
    margin-bottom: 20px;
}

.form-group {
    margin-bottom: 10px;
}

.form-subheading {
    position:relative;
    overflow:hidden;
}

.form-subheading:after {
    content: "";
    top: 40%;
    width: 100%;
    margin-left: 5px;
    height: 2px;
    position: absolute;
    background: rgba(81, 8, 39, 0.7);
}

.attr-buttons {
    margin-left: -20px;
    -webkit-user-select: none;
    -moz-user-select: none;
    -ms-user-select: none;
}

.rm-attr-btn {
    padding-top: 11px;
    padding-left: 5px;
    color: #d9534f;
}

.clicky {
    cursor: pointer;
}

.rm-attr-btn:hover {
    color: #c9302c;
    cursor: pointer;
    text-decoration: none;
}

.add-attr-btn {
    padding-top: 11px;
    padding-left: 5px;
    color: #5cb85c;
}

.add-attr-btn:hover {
    color: #398439;
    cursor: pointer;
    text-decoration: none;
}

.navbar .divider-vertical {
    height: 30px;
    margin: 10px 9px;
    border-right: 2px solid #A3114F;
    border-left: 1px solid #5C052A;
}

.resource-block {
    margin: 5px 80px 10px 0px;
}

.modal-open {
    overflow-y: scroll;
}

.notification-box {
    margin-top: 100px;
}

.panel-default {
    box-shadow: 1px 1px 1px 0px rgba(155, 155, 155, 1);
    border: 0px;
}

.panel-default .panel-heading {
    color: #ecf0f1;
    background-color: #333;
    border-color: #a3114f;
}

.close-light {
    color: #ecf0f1;
    opacity: .9;
}

.modal-content {
  background-color: #333;
}

.modal-body {
  background-color: #fff;
}

.modal-footer {
  background-color: #d7d7d7;
    -webkit-border-bottom-left-radius: 5px;
    -webkit-border-bottom-right-radius: 5px;
    -moz-border-radius-bottomleft: 5px;
    -moz-border-radius-bottomright: 5px;
    border-bottom-left-radius: 5px;
    border-bottom-right-radius: 5px;
}

.modal-header {
    color: #ecf0f1;
    background-color: #333;
    border-color: #a3114f;
    -webkit-border-top-left-radius: 5px;
    -webkit-border-top-right-radius: 5px;
    -moz-border-radius-topleft: 5px;
    -moz-border-radius-topright: 5px;
     border-top-left-radius: 5px;
     border-top-right-radius: 5px;
}

.header h2 {
    display: inline-block;
    vertical-align: middle;
    float: left;
    border-right: 1px solid #a0a0a0;
    padding-right: 15px;
    padding-bottom: 10px;
    margin: 0px;
    margin-right: 10px;
    margin-bottom: 20px;
    text-shadow: 1px 1px 4px #A2A2A2;
}

.header h3 {
    display: inline-block;
    vertical-align: middle;
    float: left;
    padding-right: 10px;
    padding-bottom: 10px;
    margin: 0px;
    margin-right: 10px;
    margin-bottom: 18px;
    font-size: xx-large;
}

.header hr {
    margin-top: -20px;
    margin-bottom: 20px;
    border: 0;
    border-top: 1px solid #a0a0a0;
}

.header .buttons {
    display: inline-block;
    vertical-align: middle;
    float: right;
}

.header h3 small {
    color: #6b6b6b;
}

.header h2 a {
    color: #333;
}

.header h2 a:hover {
    color: #666;
    text-decoration: none;
}

.header {
    border-bottom: 1px solid #a0a0a0;
    content: "";
    min-height: 44px;
}

#content {
    padding: 20px;
    background-color: #ececec;
    -webkit-border-bottom-left-radius: 5px;
    -webkit-border-bottom-right-radius: 5px;
    -moz-border-radius-bottomleft: 5px;
    -moz-border-radius-bottomright: 5px;
    border-bottom-left-radius: 5px;
    border-bottom-right-radius: 5px;
    box-shadow: 3px 3px 6px 0px rgba(155, 155, 155, 1);
}

#footer {
    position: fixed;
    left: 0px;
    bottom: 0px;
    height: 20px;
    width: 100%;
    background: #333;
    vertical-align: middle;
    color: #ecf0f1;
    font-size: small;
}

.nav>li>a {
    padding-left: 10px;
    padding-right: 10px;
}

.navbar-right {
    margin-right: 0px;
}

.navbar {
    margin-bottom: 0px;
}

.navbar-default {
    background-color: #343434;
    border-color: #a3114f;
}
.navbar-default .navbar-brand {
    color: #ecf0f1;
}
.navbar-default .navbar-brand:hover, .navbar-default .navbar-brand:focus {
    color: #ecdbff;
}
.navbar-default .navbar-text {
    color: #ecf0f1;
}
.navbar-default .navbar-nav > li > a {
    color: #ecf0f1;
}
.navbar-default .navbar-nav > li > a:hover, .navbar-default .navbar-nav > li > a:focus {
    color: #ecdbff;
}
.navbar-default .navbar-nav > .active > a, .navbar-default .navbar-nav > .active > a:hover, .navbar-default .navbar-nav > .active > a:focus {
    color: #ecdbff;
    background-color: #a3114f;
}
.navbar-default .navbar-nav > .open > a, .navbar-default .navbar-nav > .open > a:hover, .navbar-default .navbar-nav > .open > a:focus {
    color: #ecdbff;
    background-color: #a3114f;
}
.navbar-default .navbar-toggle {
    border-color: #a3114f;
}
.navbar-default .navbar-toggle:hover, .navbar-default .navbar-toggle:focus {
    background-color: #a3114f;
}
.navbar-default .navbar-toggle .icon-bar {
    background-color: #ecf0f1;
}
.navbar-default .navbar-collapse,
.navbar-default .navbar-form {
    border-color: #ecf0f1;
}
.navbar-default .navbar-link {
    color: #ecf0f1;
}
.navbar-default .navbar-link:hover {
    color: #ecdbff;
}

@media (max-width: 767px) {
    .navbar-default .navbar-nav .open .dropdown-menu > li > a {
        color: #ecf0f1;
    }
    .navbar-default .navbar-nav .open .dropdown-menu > li > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > li > a:focus {
        color: #ecdbff;
    }
    .navbar-default .navbar-nav .open .dropdown-menu > .active > a, .navbar-default .navbar-nav .open .dropdown-menu > .active > a:hover, .navbar-default .navbar-nav .open .dropdown-menu > .active > a:focus {
        color: #ecdbff;
        background-color: #a3114f;
    }
    .navbar-collapse .nav > .divider-vertical {
        display: none;
    }
}
