<loading-panel ng-if="loading"></loading-panel>
<div ng-if="!loading">
    <heading-bar
        heading="Users"
        subheading="[[profileUser.email]]">
    </heading-bar>

    <div class="row"><div class="col-sm-6">
        <panel>
            <panel-heading>
                User
            </panel-heading>
            <panel-body>
                <dl class="dl-horizontal">
                    <dt>Email</dt>
                    <dd>[[profileUser.email]]</dd>

                    <span ng-if="isSelf">
                        <dt>Secret Key</dt>
                        <dd ng-if="!secret_key">
                            <a class="clicky" ng-click="showKey()">Click to show key!</a>
                        </dd>
                        <dd ng-if="secret_key">
                            [[secret_key]]
                            (<a class="clicky" ng-click="rotateKey()">Rotate Key</a>)
                        </dd>
                    </span>
                </dl>
            </panel-body>
       </panel>
    </div></div>


</div>
